SystemOrganization addCategory: #'NetworkTests-Kernel'!
SystemOrganization addCategory: #'NetworkTests-Protocols'!
SystemOrganization addCategory: #'NetworkTests-RFC822'!
SystemOrganization addCategory: #'NetworkTests-URI'!
SystemOrganization addCategory: #'NetworkTests-UUID'!
SystemOrganization addCategory: #'NetworkTests-Url'!

Stream subclass: #MockSocketStream
	instanceVariableNames: 'atEnd inStream outStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!MockSocketStream class methodsFor: 'instance creation' stamp: 'fbs 3/22/2004 12:46'!
on: socket
	^self basicNew initialize! !

!MockSocketStream methodsFor: 'testing' stamp: 'fbs 3/22/2004 13:08'!
atEnd
	^self inStream atEnd.! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 12:51'!
atEnd: aBoolean
	atEnd := aBoolean.! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 13:29'!
inStream
	^inStream! !

!MockSocketStream methodsFor: 'initialization' stamp: 'alain.plantec 5/28/2009 10:08'!
initialize
	super initialize.
	self resetInStream.
	self resetOutStream.! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:10'!
nextLine
	^self nextLineCrLf! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:09'!
nextLineCrLf
	^(self upToAll: String crlf).! !

!MockSocketStream methodsFor: 'accessing' stamp: 'fbs 3/22/2004 13:08'!
outStream
	^outStream! !

!MockSocketStream methodsFor: 'stream in' stamp: 'PeterHugossonMiller 9/3/2009 10:05'!
resetInStream
	inStream := String new writeStream.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'PeterHugossonMiller 9/3/2009 10:05'!
resetOutStream
	outStream := String new writeStream.! !

!MockSocketStream methodsFor: 'stream out' stamp: 'fbs 3/22/2004 13:07'!
sendCommand: aString
	self outStream
		nextPutAll: aString;
		nextPutAll: String crlf.! !

!MockSocketStream methodsFor: 'stream in' stamp: 'fbs 3/22/2004 13:09'!
upToAll: delims
	^self inStream upToAll: delims.! !

ClassTestCase subclass: #FileUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!FileUrlTest methodsFor: 'testing' stamp: 'fbs 2/2/2005 12:43'!
testAsString
	| target url |
	target := 'file://localhost/etc/rc.conf'.
	url := target asUrl.
	self assert: url asString = target.
		! !

ClassTestCase subclass: #GenericUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!GenericUrlTest methodsFor: 'testing' stamp: 'fbs 2/2/2005 12:56'!
testAsString
	| url |
	url := GenericUrl new schemeName: 'sip' locator: 'foo@bar'.
	self assert: url asString = 'sip:foo@bar'.! !

ClassTestCase subclass: #HierarchicalUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!HierarchicalUrlTest methodsFor: 'testing' stamp: 'fbs 2/2/2005 13:03'!
testAsString
	| url |
	url := HierarchicalUrl new
		schemeName: 'ftp'
		authority: 'localhost'
		path: #('path' 'to' 'file')
		query: 'aQuery'.
	self assert: url asString = 'ftp://localhost/path/to/file?aQuery'.! !

ClassTestCase subclass: #SocketStreamTest
	instanceVariableNames: 'clientStream serverStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Kernel'!

!SocketStreamTest methodsFor: 'setup' stamp: 'ar 8/2/2010 18:10'!
setUp
	| listener clientSocket serverSocket |
	listener := Socket newTCP.
	[listener listenOn: 0 backlogSize: 4.

	clientSocket := Socket newTCP.
	clientSocket connectTo: #[127 0 0 1] port: listener localPort.
	clientSocket waitForConnectionFor: 1.
	self assert: clientSocket isConnected.

	serverSocket := listener waitForAcceptFor: 1.
	self assert: serverSocket isConnected.
	] ensure:[listener destroy].

	clientStream := SocketStream on: clientSocket.
	serverStream := SocketStream on: serverSocket.
! !

!SocketStreamTest methodsFor: 'setup' stamp: 'ar 8/2/2010 17:59'!
tearDown
	clientStream ifNotNil:[clientStream destroy].
	serverStream ifNotNil:[serverStream destroy].! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/5/2010 12:20'!
testNextIntoClose
	"Ensure that #next:into: will function properly when the connection is closed"

	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream next: 100 into: (String new: 100) startingAt: 1) 
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/5/2010 12:20'!
testNextIntoCloseNonSignaling
	"Ensure that #next:into: will function properly when the connection is closed"

	serverStream shouldSignal: false.
	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream next: 100 into: (String new: 100) startingAt: 1)
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpTo
	"Tests correct behavior of #upTo:"

	clientStream nextPutAll:'A line of text', String cr, 'with more text'; flush.
	self assert: (serverStream upTo: Character cr) = 'A line of text'.
	[(Delay forSeconds: 1) wait.
	clientStream nextPutAll: String cr; flush] fork.
	self assert: (serverStream upTo: Character cr) = 'with more text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToAfterCloseNonSignaling
	"Tests correct behavior of #upToAll"

	| resp |
	clientStream nextPutAll: 'A line of text'.
	clientStream close.
	serverStream shouldSignal: false.
	self shouldnt: [resp := serverStream upTo: Character cr] raise: ConnectionClosed.
	self assert: resp = 'A line of text'.! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToAfterCloseSignaling
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text'.
	clientStream close.
	self should: [serverStream upTo: Character cr] raise: ConnectionClosed.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:29'!
testUpToAll
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text', String crlf, 'with more text'; flush.
	self assert: (serverStream upToAll: String crlf) = 'A line of text'.
	[(Delay forSeconds: 1) wait.
	clientStream nextPutAll: String crlf; flush] fork.
	self assert: (serverStream upToAll: String crlf) = 'with more text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:02'!
testUpToAllAfterCloseNonSignaling
	"Tests correct behavior of #upToAll"

	| resp |
	clientStream nextPutAll: 'A line of text'.
	clientStream close.
	serverStream shouldSignal: false.
	self shouldnt: [resp := serverStream upToAll: String crlf] raise: ConnectionClosed.
	self assert: resp = 'A line of text'.! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:26'!
testUpToAllAfterCloseSignaling
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll:'A line of text'.
	clientStream close.
	self should: [serverStream upToAll: String crlf] raise: ConnectionClosed.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:48'!
testUpToAllLimit
	"Tests correct behavior of #upToAll:limit:"

	clientStream nextPutAll:'A line of text'; flush.
	self assert: (serverStream upToAll: String crlf limit: 5) = 'A line of text'.! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:11'!
testUpToAllTimeout
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll: 'A line of text'.
	serverStream timeout: 1.
	self should: [serverStream upToAll: String crlf] raise: ConnectionTimedOut.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/5/2010 12:20'!
testUpToEndClose
	"Ensure that #upToEnd will function properly when the connection is closed"

	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream upToEnd) 
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/5/2010 12:20'!
testUpToEndCloseNonSignaling
	"Ensure that #upToEnd will function properly when the connection is closed"

	serverStream shouldSignal: false.
	clientStream nextPutAll:'A line of text'; flush.
	[(Delay forMilliseconds: 100) wait.
	clientStream close] fork.
	self assert: (serverStream upToEnd)
		equals: 'A line of text'.
! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:49'!
testUpToMax
	"Tests correct behavior of #upToAll:max:"

	clientStream nextPutAll:'A line of text'; flush.
	self assert: (serverStream upTo: Character cr limit: 5) = 'A line of text'.! !

!SocketStreamTest methodsFor: 'stream protocol' stamp: 'ar 8/2/2010 18:32'!
testUpToTimeout
	"Tests correct behavior of #upToAll"

	clientStream nextPutAll: 'A line of text'.
	serverStream timeout: 1.
	self should: [serverStream upTo: Character cr] raise: ConnectionTimedOut.
! !

ClassTestCase subclass: #UrlTest
	instanceVariableNames: 'url baseUrl expected string'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Url'!

!UrlTest commentStamp: '<historical>' prior: 0!
This is the unit test for the class Url. Unit tests are a good way to exercise the functionality of your system in a repeatable and automatic manner. They are therefore recommended if you plan to release anything. For more information, see: 
	- http://www.c2.com/cgi/wiki?UnitTest
	- there is a chapter in the PharoByExample book (http://pharobyexample.org)
	- the sunit class category!

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:58'!
testAbsoluteBrowser

	url := Url absoluteFromText: 'browser:bookmarks#mainPart'.

	self assert: url schemeName = 'browser'.
	self assert: url locator = 'bookmarks'.
	self assert:url fragment = 'mainPart'.
	self assert: url class = BrowserUrl.
	! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:29'!
testAbsoluteFILE
	
	url := Url absoluteFromText: 'file:/etc/passwd#foo'.

	self assert: url schemeName = 'file'.
	self assert: url path first = 'etc'.
	self assert: url path size = 2.	
	self assert: url fragment = 'foo'.! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:32'!
testAbsoluteFILE2
	
	url := 'fILE:/foo/bar//zookie/?fakequery/#fragger' asUrl.

	self assert: url schemeName = 'file'.
	self assert: url class = FileUrl.
	self assert: url path first ='foo'.
	self assert: url path size = 5.
	self assert: url fragment = 'fragger'.! !

!UrlTest methodsFor: 'tests' stamp: 'gk 2/12/2004 21:30'!
testAbsoluteFILE3
	"Just a few selected tests for FileUrl, not complete by any means."


	{'file:'. 'file:/'. 'file://'} do: [:s |
	 	url := FileUrl absoluteFromText: s.
		self assert: (url asString = 'file:///').
		self assert: (url host = '').
		self assert: url isAbsolute].
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/file.txt'.
	self assert: (url asString = 'file://localhost/dir/file.txt').
	self assert: (url host = 'localhost').
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/file.txt'.
	self assert: (url asString = 'file://localhost/dir/file.txt').
	self assert: (url host = 'localhost').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'file:///dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self assert: (url host = '').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: '/dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'dir/file.txt'.
	self assert: (url asString = 'file:///dir/file.txt').
	self deny: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'c:/dir/file.txt'.
	self assert: (url asString = 'file:///c%3A/dir/file.txt').
	self assert: url isAbsolute.
	
	"Only a drive letter doesn't refer to a directory."
	url := FileUrl absoluteFromText: 'c:'.
	self assert: (url asString = 'file:///c%3A/').
	self assert: url isAbsolute.
	
	url := FileUrl absoluteFromText: 'c:/'.
	self assert: (url asString = 'file:///c%3A/').
	self assert: url isAbsolute! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:05'!
testAbsoluteFTP
	
	url := 'ftP://some.server/some/directory/' asUrl.

	self assert: url schemeName = 'ftp'.
	self assert: url class = FtpUrl.
	self assert: url authority = 'some.server'.	
	self assert: url path first = 'some'.
	self assert: url path size  = 3.
	! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:05'!
testAbsoluteHTTP
	
	url := 'hTTp://chaos.resnet.gatech.edu:8000/docs/java/index.html?A%20query%20#part' asUrl.

	self assert: url schemeName = 'http'.
	self assert: url authority = 'chaos.resnet.gatech.edu'.
	self assert: url path first = 'docs'.
	self assert: url path size = 3.
	self assert: url query = 'A%20query%20'.
	self assert: url fragment = 'part'.! !

!UrlTest methodsFor: 'tests' stamp: 'md 1/5/2004 14:51'!
testAbsolutePortErrorFix
	
	self shouldnt: [Url absoluteFromText: 'http://swikis.ddo.jp:8823/'] raise: Error.

	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:-1/'] raise: Error.
	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:65536/'] raise: Error.
	self should: [Url absoluteFromText: 'http://swikis.ddo.jp:auau/'] raise: Error.! !

!UrlTest methodsFor: 'tests' stamp: 'md 4/21/2003 13:08'!
testAbsoluteTELNET
	
	url := 'telNet:chaos.resnet.gatech.edu#goo' asUrl.

	self assert: url schemeName = 'telnet'.
	self assert: url locator = 'chaos.resnet.gatech.edu'.
	self assert: url fragment = 'goo'.	
! !

!UrlTest methodsFor: 'tests' stamp: 'st 9/27/2004 15:48'!
testCombineWithRelative
	#(#('http://www.rfc1149.net/' 'foo.html' 'http://www.rfc1149.net/foo.html') #('http://www.rfc1149.net/index.html' 'foo.html' 'http://www.rfc1149.net/foo.html') #('http://www.rfc1149.net/devel/' '../sam/' 'http://www.rfc1149.net/sam/') #('http://www.rfc1149.net/devel/index.html' '../sam/' 'http://www.rfc1149.net/sam/')) 
		do: [:a | self assert: (Url combine: a first withRelative: a second) = a third]! !

!UrlTest methodsFor: 'testing' stamp: 'bp 2/12/2005 20:21'!
testFromFileNameOrUrlString

	url := Url absoluteFromFileNameOrUrlString: 'asdf'.
	self assert: url schemeName = 'file'.
	self assert: url fragment isNil.
	self assert: url class = FileUrl.

	url := Url absoluteFromFileNameOrUrlString: 'http://209.143.91.36/super/SuperSwikiProj/AAEmptyTest.001.pr'.
	self assert: url schemeName = 'http'.
	self assert: url fragment isNil.
	self assert: url class = HttpUrl.! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFILE
	
	| url2 |
	baseUrl := 'file:/some/dir#fragment1' asUrl.
	url := baseUrl newFromRelativeText: 'file:../another/dir/#fragment2'.
	self assert: url asText =  'file:///another/dir/#fragment2'.
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/dir2/file.txt'.
	url2 := FileUrl absoluteFromText: 'file://hostname/flip/file.txt'.
	url2 privateInitializeFromText: '../file2.txt' relativeTo: url.
	self assert: (url2 asString = 'file://localhost/dir/file2.txt').
	self assert: (url2 host = 'localhost').
	self assert: url2 isAbsolute.
	
	url := FileUrl absoluteFromText: 'file://localhost/dir/dir2/file.txt'.
	url2 := FileUrl absoluteFromText: 'flip/file.txt'.
	self deny: url2 isAbsolute.
	url2 privateInitializeFromText: '.././flip/file.txt' relativeTo: url.
	self assert: (url2 asString = 'file://localhost/dir/flip/file.txt').
	self assert: (url2 host = 'localhost').
	self assert: url2 isAbsolute.
	
! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'ftp://a.b'.

	self assert: url asString =  'ftp://a.b/'.! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP2
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'ftp:xyz'.


	self assert: url asString =  'ftp://somewhere/some/dir/xyz'.! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeFTP3
	
	baseUrl := 'ftp://somewhere/some/dir/?query#fragment' asUrl.
	url := baseUrl newFromRelativeText: 'http:xyz'.

	self assert: url asString = 'http://xyz/'.! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:21'!
testRelativeHTTP
	
	baseUrl := 'http://some.where/some/dir?query1#fragment1' asUrl.
	url := baseUrl newFromRelativeText: '../another/dir/?query2#fragment2'.

	self assert: url asString =  'http://some.where/another/dir/?query2#fragment2'.! !

!UrlTest methodsFor: 'tests' stamp: 'gk 2/12/2004 21:31'!
testRoundTripFILE
	"File URLs should round-trip OK. This test should ultimately be
	tested on all platforms."

	| fileName |
	fileName := FileDirectory default fullNameFor: 'xxx.st'.
	url := FileDirectory urlForFileNamed: fileName.
	self assert: (url pathForFile = fileName) description: 'fileName didn''t round-trip'.! !

!UrlTest methodsFor: 'tests' stamp: 'GabrielOmarCotelli 5/25/2010 21:22'!
testUsernamePassword
	"basic case with a username+password specified"

	url := 'http://user:pword@someserver.blah:8000/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"basic case for a relative url"
	baseUrl := 'http://anotherserver.blah:9999/somedir/someotherdir/stuff/' asUrl.
	url := 'http://user:pword@someserver.blah:8000/root/index.html' asUrlRelativeTo: baseUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"a true relative test that should keep the username and password from the base URL"
	baseUrl := 'http://user:pword@someserver.blah:8000/root/index.html' asUrl.
	url := '/anotherdir/stuff/' asUrlRelativeTo: baseUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'anotherdir' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"just a username specified"
	url := 'http://user@someserver.blah:8000/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port = 8000 ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password isNil ].	"the port is not specified"
	url := 'http://user:pword@someserver.blah/root/index.html' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port isNil ].
	self should: [ url path first = 'root' ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"neither a path nor a port is specified"
	url := 'http://user:pword@someserver.blah' asUrl.
	self should: [ url schemeName = 'http' ].
	self should: [ url authority = 'someserver.blah' ].
	self should: [ url port isNil ].
	self should: [ url username = 'user' ].
	self should: [ url password = 'pword' ].	"relative URL where the username+password should be forgotten"
	baseUrl := 'http://user:pword@someserver.blah' asUrl.
	url := 'http://anotherserver.blah' asUrlRelativeTo: baseUrl.
	self should: [ url username isNil ].
	self should: [ url password isNil ]! !

!UrlTest methodsFor: 'tests' stamp: 'StephaneDucasse 5/9/2010 20:37'!
testUsernamePasswordEncoded2
	"Sometimes, weird usernames or passwords are necessary in applications, and, thus, we might receive them in a Url. The @ and the : ar the kind of critical ones."

	#(      "('user' 'pword' 'host' port 'path')"
	('Stphane rst Pckler' 'leckerEis' 'cottbus.brandenburg' 80 'mein/Zuhause')
	('Jeannde.d''Arc' 'jaiunescret' 'orleans' 8080 'une/deux/trois')
	('HaXor@roxor:fnac' 'my~Pa$wert' 'cbase' 42 'do/not_try')
	) do: [:urlParts | |theUrl|
			theUrl := ('http://{1}:{2}@{3}:{4}/{5}' format: {
				(urlParts at: 1) encodeForHTTP. 
				(urlParts at: 2) encodeForHTTP.
				urlParts at: 3. urlParts at: 4. urlParts at: 5.
			}) asUrl.
		self assert: (theUrl schemeName = 'http').
		self assert: (theUrl username = (urlParts at: 1)).
		self assert: (theUrl password = (urlParts at: 2)).
		self assert: (theUrl authority = (urlParts at: 3)).
		self assert: (theUrl port = (urlParts at: 4)).
		self assert: theUrl path first = ((urlParts at: 5) copyUpTo: $/ )]! !

!UrlTest methodsFor: 'tests' stamp: 'fbs 2/2/2005 13:22'!
testUsernamePasswordPrinting

	#(	'http://user:pword@someserver.blah:8000/root/index.html'
		'http://user@someserver.blah:8000/root/index.html' 
		'http://user:pword@someserver.blah/root/index.html'
	) do: [ :urlText |
		self should: [ urlText = urlText asUrl asString ] ].

! !

!UrlTest methodsFor: 'tests' stamp: 'StephaneDucasse 5/9/2010 20:28'!
testUsernamePasswordPrintingEncoded
	
	#('http://F%C3%BCrst%20P%C3%BCckler:leckerEis@cottbus.brandenburg:80/mein/Zuhause'
	'http://Jeannde.d%27Arc:jaiunes%C3%A9cret@orleans:8080/une/deux/trois'
	'http://HaXor%40roxor%3Afnac:my%7EPa%24%C2%A7wert@cbase:42/do/not_try') 
		do: [ :urlText |
			self should: [ urlText = urlText asUrl asString ] ].! !

TestCase subclass: #HTTPSocketTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Protocols'!

!HTTPSocketTest methodsFor: 'tests' stamp: 'StephaneDucasse 3/27/2010 22:24'!
expandUrl
	"self debug: #expandUrl"
	
	self assert: (HTTPSocket expandUrl: 'www.pharo-project.org' ip: #[127 0 0 1] port: 8080) = 'www.pharo-project.org'.
	self assert: (HTTPSocket expandUrl: '../beam' ip: #[127 0 0 1] port: 8080) = '127.0.0.1:8080/beam'.
	self assert: (HTTPSocket expandUrl: '/beam' ip: #[127 0 0 1] port: 8080) = '127.0.0.1:8080/beam'.! !

!HTTPSocketTest methodsFor: 'tests' stamp: 'StephaneDucasse 3/27/2010 22:36'!
testExpandUrl
	"self debug: #testExpandUrl"
	
	self assert: (HTTPSocket expandUrl: 'www.pharo-project.org' ip: #[127 0 0 1] port: 8080) = 'www.pharo-project.org'.
	self assert: (HTTPSocket expandUrl: '../beam' ip: #[127 0 0 1] port: 8080) = '127.0.0.1:8080/beam'.
	self assert: (HTTPSocket expandUrl: '/beam' ip: #[127 0 0 1] port: 8080) = '127.0.0.1:8080/beam'.! !

!HTTPSocketTest methodsFor: 'tests' stamp: 'StephaneDucasse 3/27/2010 22:51'!
testIpPortUrlPath
	"self debug: #testIpPortUrlPath"
	
	self assert: (HTTPSocket  ip: #[127 0 0 1] port: 8080 urlPath: '/beam') = '127.0.0.1:8080/beam'! !

TestCase subclass: #MailAddressParserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-RFC822'!

!MailAddressParserTest commentStamp: '<historical>' prior: 0!
This is the unit test for the class MailAddressParser. Unit tests are a good way to exercise the functionality of your system in a repeatable and automatic manner. They are therefore recommended if you plan to release anything. For more information, see: 
	- http://www.c2.com/cgi/wiki?UnitTest
	- there is a chapter in the PharoByExample book (http://pharobyexample.org)
	- the sunit class category!

!MailAddressParserTest methodsFor: 'tests' stamp: 'sd 6/5/2005 10:31'!
testAddressesIn

	| testString correctAnswer |

	testString := 'joe@lama.com, joe2@lama.com joe3@lama.com joe4 , Not an Address <joe5@address>, joe.(annoying (nested) comment)literal@[1.2.3.4], "an annoying" group : joe1@groupie, joe2@groupie, "Joey" joe3@groupy, "joe6"."joe8"@group.com;,  Lex''s email account <lex>'.

correctAnswer := #('joe@lama.com' 'joe2@lama.com' 'joe3@lama.com' 'joe4' 'joe5@address' 'joe.literal@[1.2.3.4]' 'joe1@groupie' 'joe2@groupie' '"Joey"' 'joe3@groupy' '"joe6"."joe8"@group.com' 'lex') asOrderedCollection.

	self assert: ((MailAddressParser addressesIn: testString) =  correctAnswer).! !

TestCase subclass: #SMTPClientTest
	instanceVariableNames: 'smtp socket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-Protocols'!

!SMTPClientTest methodsFor: 'running' stamp: 'fbs 3/22/2004 13:11'!
setUp
	socket := MockSocketStream on: ''.
	smtp := SMTPClient new.
	smtp stream: socket.! !

!SMTPClientTest methodsFor: 'testing' stamp: 'fbs 3/23/2004 17:15'!
testMailFrom
	smtp mailFrom: 'frank@angband.za.org'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).
	
	socket resetOutStream.
	smtp mailFrom: '<frank@angband.za.org>'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).
	
	socket resetOutStream.
	smtp mailFrom: 'Frank <frank@angband.za.org>'.
	self assert: socket outStream contents = ('MAIL FROM: <frank@angband.za.org>', String crlf).! !

TestCase subclass: #TestURI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NetworkTests-URI'!

!TestURI commentStamp: 'mir 2/27/2002 14:42' prior: 0!
Main comment stating the purpose of this class and relevant relationship to other classes.


   Some parsers allow the scheme name to be present in a relative URI if
   it is the same as the base URI scheme.  This is considered to be a
   loophole in prior specifications of partial URI [RFC1630]. Its use
   should be avoided.

      http:g        =  http:g           ; for validating parsers
                    |  http://a/b/c/g   ; for backwards compatibility
!

!TestURI class methodsFor: 'test generation' stamp: 'sd 3/20/2008 22:28'!
generateAbnormalResolverTests
	"TestURI generateAbnormalResolverTests"

	| relURIString result method testPairs pair |

	testPairs := #(
		#('../../../g' 'http://a/../g' )
		#('../../../../g' 'http://a/../../g' )
		#('/./g' 'http://a/./g' )
		#('/../g' 'http://a/../g' )
		#('g.' 'http://a/b/c/g.' )
		#('.g' 'http://a/b/c/.g' )
		#('g..' 'http://a/b/c/g..' )
		#('..g' 'http://a/b/c/..g' )
		#('./../g' 'http://a/b/g' )
		#('./g/.' 'http://a/b/c/g/' )
		#('g/./h' 'http://a/b/c/g/h' )
		#('g/../h' 'http://a/b/c/h' )
		#('g;x=1/./y' 'http://a/b/c/g;x=1/y' )
		#('g;x=1/../y' 'http://a/b/c/y' )
		#('g?y/./x' 'http://a/b/c/g?y/./x' )
		#('g?y/../x' 'http://a/b/c/g?y/../x' )
		#('g#s/./x' 'http://a/b/c/g#s/./x' )
		#('g#s/../x' 'http://a/b/c/g#s/../x' )
	).
	1 to: testPairs size do: [:index |
		pair := testPairs at: index.
		relURIString := pair first.
		result := pair last.
		method := String streamContents: [:stream |
			stream nextPutAll: 'testResolveAbnormal' , index printString; cr.
			stream
				nextPutAll: '	| baseURI relURI resolvedURI |' ; cr;
				nextPutAll: '	baseURI := ''http://a/b/c/d;p?q'' asURI.' ; cr;
				nextPutAll: '	relURI := '; nextPut: $'; nextPutAll: relURIString; nextPutAll: '''.' ; cr;
				nextPutAll: '	resolvedURI := baseURI resolveRelativeURI: relURI.' ; cr;
				nextPutAll: '	self should: [resolvedURI asString = '''; nextPutAll: result; nextPutAll: '''].' ; cr].
		self compile: method classified: 'running resolving'].
! !

!TestURI class methodsFor: 'test generation' stamp: 'sd 3/20/2008 22:28'!
generateNormalResolverTests
	"TestURI generateNormalResolverTests"

	| relURIString result method testPairs pair |

	testPairs := #(
		#('g:h' 'g:h' )
		#('g' 'http://a/b/c/g' )
		#('./g' 'http://a/b/c/g' )
		#('g/' 'http://a/b/c/g/' )
		#('/g' 'http://a/g' )
		#('//g' 'http://g' )
		#('?y' 'http://a/b/c/?y' )
		#('g?y' 'http://a/b/c/g?y' )
		#('g#s' 'http://a/b/c/g#s' )
		#('g?y#s' 'http://a/b/c/g?y#s' )
		#(';x' 'http://a/b/c/;x' )
		#('g;x' 'http://a/b/c/g;x' )
		#('g;x?y#s' 'http://a/b/c/g;x?y#s' )
		#('.' 'http://a/b/c/' )
		#('./' 'http://a/b/c/' )
		#('..' 'http://a/b/' )
		#('../' 'http://a/b/' )
		#('../g' 'http://a/b/g' )
		#('../..' 'http://a/' )
		#('../../' 'http://a/' )
		#('../../g' 'http://a/g' )
	).
	1 to: testPairs size do: [:index |
		pair := testPairs at: index.
		relURIString := pair first.
		result := pair last.
		method := String streamContents: [:stream |
			stream nextPutAll: 'testResolveNormal' , index printString; cr.
			stream
				nextPutAll: '	| baseURI relURI resolvedURI |' ; cr;
				nextPutAll: '	baseURI := ''http://a/b/c/d;p?q'' asURI.' ; cr;
				nextPutAll: '	relURI := '; nextPut: $'; nextPutAll: relURIString; nextPutAll: '''.' ; cr;
				nextPutAll: '	resolvedURI := baseURI resolveRelativeURI: relURI.' ; cr;
				nextPutAll: '	self should: [resolvedURI asString = '''; nextPutAll: result; nextPutAll: '''].' ; cr].
		self compile: method classified: 'running resolving'].
! !

!TestURI methodsFor: 'expected failures' stamp: 'StephaneDucasse 4/4/2010 21:45'!
expectedFailures 
	^#(testRelativePathWithTrailingSlash testRelativeQuery testSlashSlashSlashPath testQueryShouldNotContainEscape testQueryWithOnlyQueryPart testRelativeAuthority testRelativeEmptyAuthority testPathWithDotDot testPathWithThreeParts testQueryShouldNotContainEsacep testQueryShouldNotContainPipes testQueryWithALotCharacters testPathWithFunkyCharacters testPathWithSimpleDot testPathWithSimpleDotDot testPathForEmptyURI testPathForSlash testPathWithBogusEscapedCharacters testParseFragment6 testParseFragment7 testParseFragment8 testEmptyButDefinedQuery testColonOnly testUserInfoWithIllegalCharacters testSchemeCannotStartWithDigit testNoEscapedCharactersInScheme testNoPlusAtTheBeginningOfScheme testSchemeShouldNotContainAt testSimpleAbsoluteQuery testNonNumericPorts testDotDotInPath)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:22'!
test2396ParseFTP
	"From section 1.3."

	| uri uriString |
	uriString := 'ftp://ftp.is.co.za/rfc/rfc1808.txt'.
	uri := URI fromString: uriString.
	self assert:  (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:26'!
test2396ParseGopher
	"From section 1.3."

	| uri uriString |
	uriString := 'gopher://spinaltap.micro.umn.edu/00/Weather/California/Los%20Angeles'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque)
	"we probably have a problem with the %20 escape character"! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:27'!
test2396ParseHTTP1
	"From section 1.3."

	| uri uriString |
	uriString := 'http://www.math.uio.no/faq/compression-faq/part1.html'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:30'!
test2396ParseHTTP2
	"From appendix B."

	| uri uriString |
	uriString := 'http://www.ics.uci.edu/pub/ietf/uri/#Related'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri fragment = 'Related')! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:31'!
test2396ParseMailto
	"From section 1.3."

	| uri uriString |
	uriString := 'mailto:mduerst@ifi.unizh.ch'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:32'!
test2396ParseNew
	"From section 1.3."

	| uri uriString |
	uriString := 'news:comp.infosystems.www.servers.unix'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque)! !

!TestURI methodsFor: 'tests 2396' stamp: 'StephaneDucasse 4/4/2010 21:33'!
test2396ParseTelnet
	"From section 1.3."

	| uri uriString |
	uriString := 'telnet://melvyl.ucop.edu/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque)! !

!TestURI methodsFor: 'tests authority' stamp: 'StephaneDucasse 4/2/2010 22:04'!
testAbsoluteAuthority
	"self debug: #testAbsoluteAuthority"
	
	| uri absoluteURIString |
	"An absolute URI with authority. An absolute URI starts with a scheme:"
	absoluteURIString := 'http://www.pharo-project.org'. 
	uri := URI fromString: absoluteURIString.
	self assert: (uri asString = absoluteURIString).
	self assert: (uri isAbsolute).
	self assert: (uri authority asString = 'www.pharo-project.org').
	self deny: (uri isOpaque).! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:15'!
testAbsoluteMailToScheme
	"self debug: #testAbsoluteMailToScheme"
	| uri |
	"[scheme:][//authority][path][?query][#fragment]
	where authority can be [user-info@]host[:port]"
	
	uri := URI fromString: 'mailto:somebody@somewhere.nowhere'.
	self assert: (uri scheme = 'mailto').
	self assert: (uri  schemeSpecificPart = 'somebody@somewhere.nowhere').
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self deny: (uri isRelative)! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:08'!
testAbsoluteURIHavingEmptyAuthority

	self shouldnt: [URI fromString: 'http://'] raise: IllegalURIException! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:01'!
testAbsoluteURIOnlyHavingSchemeFail

	self should: [URI fromString: 'http:'] raise: IllegalURIException! !

!TestURI methodsFor: 'tests authority' stamp: 'StephaneDucasse 4/3/2010 13:14'!
testAbsoluteURIWithSimpleAuthority
	"self debug: #testAbsoluteURIWithSimpleAuthority"
	
	| uri uriString | 
	uriString := 'http://www.pharo-project.org'.			"An absolute URI with empty (but defined) authority."
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri authority asString = 'www.pharo-project.org').
	self assert: (uri scheme = 'http').
	self assert: (uri schemeIsHttp).
	self deny: (uri isOpaque).
	! !

!TestURI methodsFor: 'tests authority' stamp: 'StephaneDucasse 4/3/2010 12:06'!
testAbsolutionButEmptyURIAuthority
	"self debug: #testAbsolutionButEmptyURIAuthority"
	
	| uri uriString | 
	uriString := 'scheme://'.			"An absolute URI with empty (but defined) authority."
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri authority isNil).
	self deny: (uri isOpaque).
	! !

!TestURI methodsFor: 'expected failures' stamp: 'StephaneDucasse 4/3/2010 12:00'!
testColonOnly
	"If there's a colon, there's a scheme.  Supposed to be, anyway."

	self should: [URI fromString: '://host/']
		raise: IllegalURIException! !

!TestURI methodsFor: 'running file' stamp: 'StephaneDucasse 4/2/2010 22:13'!
testDefaultDirRoundtrip
	"self debug:#testDefaultDirRoundtrip"
	
	| defaultDir defaultDirURI uriDir |
	defaultDir := FileDirectory default.
	defaultDirURI := defaultDir uri.
	uriDir := FileDirectory uri: defaultDirURI.
	self assert: (defaultDir fullName = uriDir fullName)! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/27/2010 10:14'!
testDirWithHash
	"Tests proper escaping of directories with hash mark"
	"self debug: #testDirWithHash"
	| uriDir origPath origDir dirURI |
	origPath := FileDirectory default pathName, '#123'.
	origDir := FileDirectory on: origPath.
	self assert: origDir pathName = origPath.
	dirURI := origDir uri.
	uriDir := FileDirectory uri: dirURI.
	self assert: origDir fullName = uriDir fullName! !

!TestURI methodsFor: 'running file' stamp: 'StephaneDucasse 4/2/2010 22:13'!
testDirectoryRoot

	| rootDir uriRoot uriDir |
	rootDir := FileDirectory root.
	uriRoot := 'file:///' asURI.
	self assert: uriRoot isAbsolute.
	uriDir := FileDirectory uri: uriRoot.
	self assert: (rootDir fullName = uriDir fullName)! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 18:44'!
testDotDotInPath
	
	| uri uriString |
	uriString := '/../../path/to/resource'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self assert: (uri path size = 6).
	"do we cut in chunk the path"! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 13:16'!
testEmptyButDefinedQuery
	"Empty (but defined) query."

	| uri uriString |
	uriString := 'scheme:/path/to/resource?'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri query = '').! !

!TestURI methodsFor: 'tests ports' stamp: 'StephaneDucasse 4/3/2010 17:48'!
testHostWithPort

	| uri uriString |
	"[scheme:][//authority][path][?query][#fragment]
	where authority can be [user-info@]host[:port]"
	
	uriString := 'http://host:123/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri authority port = 123).
! !

!TestURI methodsFor: 'expected failures' stamp: 'StephaneDucasse 4/3/2010 12:18'!
testNoEscapedCharactersInScheme
	"No escaped characters in the scheme."

	self should: [URI fromString: 'sch%65me://host/']
		raise: IllegalURIException
! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/3/2010 23:46'!
testNoPathOnlyAuthority


	| uri uriString |
	uriString := 'scheme://host'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri path = '').! !

!TestURI methodsFor: 'expected failures' stamp: 'StephaneDucasse 4/3/2010 12:22'!
testNoPlusAtTheBeginningOfScheme
	"Digits and + and - and . may be allowed, but not at the beginning."

	self should: [URI fromString: '+scheme://host/']
		raise: IllegalURIException.
	self should: [URI fromString: '-scheme://host/']
		raise: IllegalURIException.
	self should: [URI fromString: '.scheme://host/']
		raise: IllegalURIException.
	self shouldnt: [URI fromString: 'sche-me://host/']
		raise: IllegalURIException.
	self shouldnt: [URI fromString: 'sche+me://host/']
		raise: IllegalURIException.
	self shouldnt: [URI fromString: 'sche.me://host/']
		raise: IllegalURIException
! !

!TestURI methodsFor: 'tests ports' stamp: 'StephaneDucasse 4/3/2010 18:16'!
testNonNumericPorts
	"Ports are numeric; non-numeric ports become part of a regName."
	"We should check the spec and see what should be done"
	| uri uriString |
	uriString := 'scheme://host:port/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri authority name = 'host:port')
! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/4/2010 00:29'!
testOpaque

	| uri uriString |
	uriString := 'scheme:opaque'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self assert: (uri schemeSpecificPart = 'opaque').! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 13:13'!
testOpaqueQuery
	"An opaque URI cannot have a query, because the opaque part may includes any $?."

	| uri uriString |
	"An opaque URI is an absolute URI whose scheme-specific part does not begin with a slash character ('/')"
	"[scheme:]scheme-specific-part[#fragment]"
	
	uriString := 'scheme:opaque?query'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self should: [ uri query] raise: Error.
! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/2/2010 22:44'!
testParseBadCharacterInUserInfo
	"self debug: #testParseBadCharacterInUserInfo"

	| uri uriString |
	uriString := 'scheme://$%%&**()!!.@host/'.
	uri := URI fromString: uriString.
	self assert: (uri authority userInfo = '$%%&**()!!.')! !

!TestURI methodsFor: 'fragment' stamp: 'StephaneDucasse 4/4/2010 21:40'!
testParseFragment1
	"Query, then fragment."

	| uri uriString |
	uriString := 'scheme://host/path/to/resource?query#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self should: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri query = '?query'].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 4/12/2003 18:25'!
testParseFragment10
	"Fragment only."

	| uri uriString |
	uriString := '#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 3/31/2003 23:37'!
testParseFragment2
	"Fragment with no query."

	| uri uriString |
	uriString := 'scheme://host/path/to/resource#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self should: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri query isNil].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'StephaneDucasse 4/4/2010 21:40'!
testParseFragment3
	"Relative path, query, then fragment."

	| uri uriString |
	uriString := '/path/to/resource?query#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri query = '?query'].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 4/12/2003 18:26'!
testParseFragment4
	"Relative path, fragment with no query."

	| uri uriString |
	uriString := '/path/to/resource#fragment'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self shouldnt: [uri isOpaque].
	self should: [uri query isNil].
	self should: [uri fragment = 'fragment'].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 3/31/2003 23:40'!
testParseFragment5
	"Even opaque parts can have fragments.  The empty fragment, in fact."

	| uri uriString |
	uriString := 'scheme:opaque#'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self should: [uri isAbsolute].
	self should: [uri isOpaque].
	self should: [uri fragment = ''].! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 3/31/2003 23:45'!
testParseFragment6
	"No $# in a fragment."

	self should: [URI fromString: 'scheme:opaque#frag#ment']
		raise: IllegalURIException.


! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 3/31/2003 23:45'!
testParseFragment7
	"No $| in a fragment."

	self should: [URI fromString: 'scheme:opaque#frag|ment']
		raise: IllegalURIException.


! !

!TestURI methodsFor: 'fragment' stamp: 'BEL 4/9/2003 02:15'!
testParseFragment8
	"No illegally escaped characters in a fragment."

	self should: [URI fromString: 'scheme:opaque#frag%ment']
		raise: Error


! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 18:24'!
testPathForEmptyURI

	| uri uriString |
	uriString := ''.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self should: [uri path isNil].
	self should: [uri query isNil].
	self should: [uri fragment isNil].! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 23:43'!
testPathForSlash
	| uri uriString |
	uriString := '/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri path size = 2)! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/3/2010 23:47'!
testPathWithBogusEscapedCharacters

	self should: [URI fromString: 'scheme:/path/to/e%rror']
		raise: Error! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 19:00'!
testPathWithDotDot

	| uri uriString |
	uriString := '/../path/../to/resource'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self assert: (uri path size = 6).
		"may be we should have the path chunk"! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 18:26'!
testPathWithFunkyCharacters
	"A relative path with exciting characters."

	| uri uriString |
	uriString := ';Super@c&a=l+i$,f-r_a.g!!i~l*i''s(t)i3c%20foobar/ative/path'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self should: [uri path size = 3].! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 23:41'!
testPathWithSimpleDot


	| uri uriString |
	uriString := '/path/./to/resource'.
	uri := URI fromString: uriString.
	self assert: ( uri asString = uriString).
	self assert: (uri path size = 5).! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 23:40'!
testPathWithSimpleDotDot


	| uri uriString |
	uriString := '/path/../to/resource'.
	uri := URI fromString: uriString.
	self assert: ( uri asString = uriString).
	self assert: (uri path size = 5).! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 18:25'!
testPathWithThreeParts

	| uri uriString |
	uriString := 'rel/ative/path'.
	uri := URI fromString: uriString.
	self should: [uri asString = uriString].
	self shouldnt: [uri isAbsolute].
	self should: [uri path size = 3].! !

!TestURI methodsFor: 'tests ports' stamp: 'StephaneDucasse 4/3/2010 17:56'!
testPortNumbersShouldNotHaveEscapingCharacters
	"No escaped characters can appear in a port; they turn it into a regName."

	| uri uriString |
	uriString := 'scheme://host:1%323/'.
	uri := URI fromString: uriString.
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri authority name =  'host:1')
	"may be this should be an error?"

! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 13:41'!
testQueryShouldNotContainEscape
	"Those characters cannot escape."

	self should: [URI fromString: 'scheme:/path/to/resource?que%ry']
		raise: Error
! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 13:41'!
testQueryShouldNotContainPipes
	"No questions about pipes, please."

	self should: [URI fromString: 'scheme:/path/to/resource?que|ry']
		raise: IllegalURIException
! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 17:35'!
testQueryWithALotCharacters
	
	| uri uriString |
	uriString := 'http:/path/to/resource?Pharo| is%20h-y3"p.er!!cool '.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri query = 'http:/path/to/resource?Pharo| is h-y3"p.er!!cool ').
! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 17:42'!
testQueryWithOnlyQueryPart
	"According to the BNF, there must be something besides questions, but according to the resolution examples, a relative URI containing only a query is just fine.  Since the latter is in common usage, we deviate from the BNF."

	| uri uriString |
	uriString := '?query'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri query = 'query').! !

!TestURI methodsFor: 'tests authority' stamp: 'StephaneDucasse 4/2/2010 22:07'!
testRelativeAuthority
	"self debug: #testRelativeAuthority"
	
	| uri relativeURIString |
	"A relative URI with authority. relative uri does not start with a scheme:."
	relativeURIString := '//www.pharo-project.org'. 
	uri := URI fromString: relativeURIString.
	self assert: (uri asString = relativeURIString).
	self deny: (uri isAbsolute).
	self assert: (uri isRelative). 
	self assert: (uri authority asString =  'www.pharo-project.org').
	self deny: (uri isOpaque).! !

!TestURI methodsFor: 'tests authority' stamp: 'StephaneDucasse 4/3/2010 12:03'!
testRelativeEmptyAuthority
	"self debug: #testRelativeEmptyAuthority"
	"remember [scheme:][//authority][path][?query][#fragment]
		where authority can be [user-info@]host[:port]"
	| uri uriString |
	uriString := '//'. "A relative URI with empty (but defined) authority."
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self deny: (uri authority isNil).
	self deny: (uri isOpaque).! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 18:41'!
testRelativePathWithTrailingSlash
	
	| uri uriString |
	uriString := 'trailing/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self assert: (uri path size = 2).! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 13:05'!
testRelativeQuery
	"Relative query."

	| uri uriString |
	uriString := '/path/to/resource?query'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self deny: (uri isOpaque).
	self assert: (uri query = 'query').! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal1
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal10
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './g/.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal11
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/./h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/h'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal12
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/../h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/h'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal13
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x=1/./y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x=1/y'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal14
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x=1/../y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/y'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal15
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y/./x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y/./x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 16:12'!
testResolveAbnormal16
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y/../x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y/../x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal17
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s/./x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s/./x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal18
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s/../x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s/../x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal2
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../../g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal3
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/./g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/./g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal4
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/../g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal5
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g.'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal6
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '.g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/.g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal7
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g..'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal8
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '..g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/..g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveAbnormal9
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal1
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g:h'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'g:h'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal10
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y#s'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal11
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := ';x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/;x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal12
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal13
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g;x?y#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g;x?y#s'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal14
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '.'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal15
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal16
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal17
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal18
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal19
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../..'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal2
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal20
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal21
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '../../g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal3
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := './g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal4
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g/'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g/'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal5
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '/g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal6
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '//g'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://g'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal7
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := '?y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/?y'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal8
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g?y'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g?y'].
! !

!TestURI methodsFor: 'running resolving' stamp: 'mir 2/27/2002 14:42'!
testResolveNormal9
	| baseURI relURI resolvedURI |
	baseURI := 'http://a/b/c/d;p?q' asURI.
	relURI := 'g#s'.
	resolvedURI := baseURI resolveRelativeURI: relURI.
	self should: [resolvedURI asString = 'http://a/b/c/g#s'].
! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 18:18'!
testSchemeAbsolutePass2
	| uri |
	uri := URI fromString: 'mailto:somebody@somewhere.nowhere'.
	self assert: (uri scheme = 'mailto').
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self deny: (uri isRelative)! !

!TestURI methodsFor: 'parsing tests' stamp: 'jannik.laval 5/2/2010 07:42'!
testSchemeAbsolutePass3
	| uri |
	uri := URI fromString: 'ftp://ftp@pharo.org'.
	self assert: (uri scheme = 'ftp').
	self assert: uri isAbsolute.
	self deny: (uri isOpaque).
	self deny: (uri isRelative).
	self assert: (uri userInfo = 'ftp').
	self assert: (uri host = 'pharo.org').
	self assert: (uri port isNil).
! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 18:21'!
testSchemeAbsolutePass4
	| uri |
	uri := URI fromString: 'mailto:somebody@somewhere.nowhere#fragment'.
	self assert: (uri scheme = 'mailto').
	self assert: (uri isAbsolute).
	self assert: (uri isOpaque).
	self deny: (uri isRelative).
	self assert: (uri fragment = 'fragment').

! !

!TestURI methodsFor: 'parsing tests' stamp: 'VeronicaUquillas 6/11/2010 13:43'!
testSchemeAbsolutePass5
	| uri |
	uri := URI fromString: 'http://www.pharo-project.org#fragment'.
	self assert: (uri scheme = 'http').
	self assert: (uri isAbsolute).
	self deny: (uri isOpaque).
	self deny: (uri isRelative).
	self assert: (uri fragment = 'fragment').
! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:56'!
testSchemeCanContainPlusMinus
	"Digits and + and - and . are allowed."

	| uri uriString |
	uriString := 's-c+h.e1mE://host/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri scheme = 's-c+h.e1mE').! !

!TestURI methodsFor: 'parsing tests' stamp: 'StephaneDucasse 4/3/2010 12:17'!
testSchemeCannotStartWithDigit
	"A scheme cannot begin with a digit."

	self should: [URI fromString: '69cheme://host/']
		raise: IllegalURIException
! !

!TestURI methodsFor: 'expected failures' stamp: 'StephaneDucasse 4/3/2010 12:57'!
testSchemeShouldNotContainAt
	"No @ in a scheme."

	self should: [URI fromString: 'sch@eme://host/']
		raise: IllegalURIException.
! !

!TestURI methodsFor: 'tests query' stamp: 'StephaneDucasse 4/3/2010 12:59'!
testSimpleAbsoluteQuery
	"Absolute query."

	| uri uriString |
	uriString := 'scheme://host/path/to/resource?query'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri query = 'query').! !

!TestURI methodsFor: 'test path' stamp: 'StephaneDucasse 4/3/2010 23:44'!
testSlashSlashSlashPath
	
	| uri uriString |
	uriString := '///'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self deny: (uri isAbsolute).
	self assert: (uri authority host asString = '').
	self assert: (uri path size = 2).! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/2/2010 22:38'!
testUserInfo
	"self debug: #testUserInfo"
	
	| uri uriString |
	"[scheme:][//authority][path][?query][#fragment]
	where authority can be [user-info@]host[:port]"

	uriString := 'scheme://userinfo@host/'.
	uri :=  URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri authority userInfo = 'userinfo').! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/2/2010 22:52'!
testUserInfoNoQuestionMark
	"No ? in the userInfo; it turns everything into a query."
	"self debug: #testUserInfoNoQuestionMark"
	
	| uri uriString |
	"[scheme:][//authority][path][?query][#fragment]
	where authority can be [user-info@]host[:port]"
	
	uriString := 'scheme://user?info@host/'.
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri authority host asString = 'user')! !

!TestURI methodsFor: 'tests user info' stamp: 'StephaneDucasse 4/2/2010 22:40'!
testUserInfoOnlyHost
	"self debug: #testUserInfoOnlyHost"
	
	| uri uriString |
	uriString := 'scheme://@host/'.
	"Empty but not undefined userinfo."
	
	uri := URI fromString: uriString.
	self assert: (uri asString = uriString).
	self assert: (uri authority userInfo = '').! !

!TestURI methodsFor: 'expected failures' stamp: 'StephaneDucasse 4/3/2010 12:01'!
testUserInfoWithIllegalCharacters
	"self debug: #testUserInfoWithIllegalCharacters"

	self should: [URI fromString: 'scheme://user%aeinfo@host/']
		raise: Error.
		
	"strange Escaped octets, that is, triplets consisting of the percent character ('%') followed by two hexadecimal digits ('0'-'9', 'A'-'F', and 'a'-'f')"! !

TestCase subclass: #UUIDPrimitivesTest
	instanceVariableNames: ''
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'NetworkTests-UUID'!

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:14'!
testCreation
	| uuid |
	uuid := UUID new.
	self should: [uuid size = 16].
	self shouldnt: [uuid isNilUUID].
	self should: [uuid asString size = 36].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:27'!
testCreationEquality
	| uuid1 uuid2 |
	uuid1 := UUID new.
	uuid2 := UUID new.
	self should: [uuid1 = uuid1].
	self should: [uuid2 = uuid2].
	self shouldnt: [uuid1 = uuid2].
	self shouldnt: [uuid1 hash = uuid2 hash].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:17'!
testCreationFromString
	| uuid string |
	string := UUID nilUUID asString.
	uuid := UUID fromString: string.
	self should: [uuid size = 16].
	self should: [uuid = UUID nilUUID].
	self should: [uuid isNilUUID].
	self should: [uuid asString size = 36].
	self should: [uuid asArray asSet size = 1].
	self should: [(uuid asArray asSet asArray at: 1) = 0].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:18'!
testCreationFromStringNotNil
	| uuid string |
	string := UUID new asString.
	uuid := UUID fromString: string.
	self should: [uuid size = 16].
	self should: [uuid asString size = 36].

! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'JMM 11/22/2001 17:16'!
testCreationNil
	| uuid |
	uuid := UUID nilUUID.
	self should: [uuid size = 16].
	self should: [uuid isNilUUID].
	self should: [uuid asString size = 36].
	self should: [uuid asArray asSet size = 1].
	self should: [(uuid asArray asSet asArray at: 1) = 0].
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 1/5/2010 15:59'!
testCreationNodeBased
	

	(UUID new asString last: 12) = (UUID new asString last: 12) ifFalse: [^self].
	1000 timesRepeat:
		[ | uuid |uuid := UUID new.
		self should: [((uuid at: 7) bitAnd: 16rF0) = 16r10].
		self should: [((uuid at: 9) bitAnd: 16rC0) = 16r80]]
! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 1/5/2010 15:59'!
testDuplicationsKinda
	| check size |

	size := 5000.
	check := Set new: size.
	size timesRepeat: 
		[ | uuid |uuid := UUID new.
		self shouldnt: [check includes: uuid].
		check add: uuid].
		! !

!UUIDPrimitivesTest methodsFor: 'tests' stamp: 'nice 1/5/2010 15:59'!
testOrder
	
	100 timesRepeat:
		[ | uuid1 uuid2 |uuid1 := UUID new.
		uuid2 := UUID new.
		(uuid1 asString last: 12) = (uuid2 asString last: 12) ifTrue:
			[self should: [uuid1 < uuid2].
			self should: [uuid2 > uuid1].
			self shouldnt: [uuid1 = uuid2]]]
! !
